@@ -1,16 +1,25 @@
 #' Hyperbolic Transformations
 #'
-#' \code{step_hyperbolic} creates a \emph{specification} of a recipe step that
-#'   will transform data using a hyperbolic function.
+#' `step_hyperbolic` creates a *specification* of a
+#'  recipe step that will transform data using a hyperbolic
+#'  function.
 #'
 #' @inheritParams step_center
-#' @inherit step_center return
-#' @param role Not used by this step since no new variables are created.
-#' @param func A character value for the function. Valid values are "sin",
-#'   "cos", or "tan".
+#' @param ... One or more selector functions to choose which
+#'  variables are affected by the step. See [selections()]
+#'  for more details.  For the `tidy` method, these are not
+#'  currently used.
+#' @param role Not used by this step since no new variables are
+#'  created.
+#' @param func A character value for the function. Valid values
+#'  are "sin", "cos", or "tan".
 #' @param inverse A logical: should the inverse function be used?
-#' @param columns A character string of variable names that will be (eventually)
-#'   populated by the \code{terms} argument.
+#' @param columns A character string of variable names that will
+#'  be (eventually) populated by the `terms` argument.
+#' @return An updated version of `recipe` with the new step
+#'  added to the sequence of existing steps (if any). For the
+#'  `tidy` method, a tibble with columns `terms` (the
+#'  columns that will be affected), `inverse`, and `func`.
 #' @keywords datagen
 #' @concept preprocessing transformation_methods
 #' @export
@@ -29,9 +38,12 @@
 #'
 #' transformed_te <- bake(cos_obj, examples)
 #' plot(examples$V1, transformed_te$V1)
-#' @seealso \code{\link{step_logit}} \code{\link{step_invlogit}}
-#'   \code{\link{step_log}}  \code{\link{step_sqrt}} \code{\link{recipe}}
-#'   \code{\link{prep.recipe}} \code{\link{bake.recipe}}
+#'
+#' tidy(cos_trans, number = 1)
+#' tidy(cos_obj, number = 1)
+#' @seealso [step_logit()] [step_invlogit()]
+#'   [step_log()]  [step_sqrt()] [recipe()]
+#'   [prep.recipe()] [bake.recipe()]
 
 step_hyperbolic <-
   function(recipe,
@@ -110,3 +122,12 @@ print.step_hyperbolic <-
     printer(x$columns, x$terms, x$trained, width = width)
     invisible(x)
   }
+
+#' @rdname step_hyperbolic
+#' @param x A `step_hyperbolic` object.
+tidy.step_hyperbolic <- function(x, ...) {
+  out <- simple_terms(x, ...)
+  out$inverse <- x$inverse
+  out$func <- x$func
+  out
+}
